@@ -1,10 +1,53 @@
 /*!
+
 # Plotters - Another Plotting Library in Rust
 
+<a href="https://crates.io/crates/plotters">
+    <img style="display: inline!important" src="https://img.shields.io/crates/v/plotters.svg"></img>
+</a>
+
+<a href="https://docs.rs/plotters">
+    <img style="display: inline!important" src="https://docs.rs/plotters/badge.svg"></img>
+</a>
+
+
+
 Plotters is a flexible drawing library for data visualization written in pure Rust.
 The library isn't aimed supporting different types of plotting, but a generic platform
 that can be extended to support different types of visualization methods.
 
+## Gallery
+
+<div class="galleryItem">
+    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/sample.png">
+        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/sample.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Multiple Plot
+        <a href="https://github.com/38/plotters/blob/master/examples/chart.rs">[code]</a>
+    </div>
+</div>
+
+<div class="galleryItem">
+    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/stock.png">
+        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/stock.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Candlestick Plot
+        <a href="https://github.com/38/plotters/blob/master/examples/stock.rs">[code]</a>
+    </div>
+</div>
+
+<div class="galleryItem">
+    <a href="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/histogram.png">
+        <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/histogram.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Candlestick Plot
+        <a href="https://github.com/38/plotters/blob/master/examples/histogram.rs">[code]</a>
+    </div>
+</div>
+
 ## Quick Start
 
 ```rust
@@ -198,6 +241,24 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
 ![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/5.png)
 
+<style>
+    img {
+            display: block;
+            margin: 0 auto;
+            max-width: 500px;
+    }
+    .galleryItem {
+            width: 250px;
+            display: inline-block;
+    }
+    .galleryImg {
+            max-width: 100%;
+    }
+    .galleryText {
+            text-align: center;
+    }
+</style>
+
 */
 pub mod chart;
 pub mod coord;
@@ -225,4 +286,10 @@ pub mod prelude {
     pub use crate::element::{
         CandleStick, Circle, Cross, EmptyElement, OwnedText, Path, Rectangle, Text,
     };
+
+    #[allow(type_alias_bounds)]
+    /// The type used to returns a drawing operation that can be failed
+    /// - `T`: The return type
+    /// - `D`: The drawing backend type
+    pub type DrawResult<T, D:DrawingBackend>=Result<T, crate::drawing::DrawingAreaErrorKind<D::ErrorType>>;
 }
